======================
Contributing to Murano
======================

If you're interested in contributing to the Murano project,
the following will help get you started.

Contributor License Agreement
=============================

In order to contribute to the Murano project, you need to have
signed OpenStack's contributor's agreement:

* https://docs.openstack.org/infra/manual/developers.html
* https://wiki.openstack.org/wiki/How_To_Contribute#Contributor_License_Agreement


Project Hosting Details
=======================

* Bug trackers
    * General murano tracker: https://launchpad.net/murano

    * Python client tracker: https://launchpad.net/python-muranoclient

    * Tracker for bugs related to specific apps: https://launchpad.net/murano-apps

* Mailing list (prefix subjects with ``[Murano]`` for faster responses)
    http://lists.openstack.org/cgi-bin/mailman/listinfo/openstack-dev

* Wiki
    https://wiki.openstack.org/wiki/Murano

* IRC channel
    * #murano at FreeNode

    * https://wiki.openstack.org/wiki/Meetings#Murano_meeting

* Code Hosting
    * https://opendev.org/openstack/murano

    * https://opendev.org/openstack/murano-agent

    * https://opendev.org/openstack/murano-dashboard

    * https://opendev.org/openstack/python-muranoclient

* Code Review
    * https://review.opendev.org/#/q/murano+AND+status:+open,n,z

    * https://docs.openstack.org/infra/manual/developers.html#development-workflow

* Murano Design Specifications
    * https://opendev.org/openstack/murano-specs
